clear
clc
%% - - - - - - - - - - - Case specific inputs - - - - - - - - - - - - - &&
% eta_0 = [7 1 -2/3*pi]';       % Case 1
% eta_end = [2 -3 deg2rad(0)]';
eta_0 = [7 -1.75 -17/18*pi]';   % Case 2
eta_end = [2 -3 deg2rad(0)]';
% eta_0 = [6 4 -7/12*pi]';      % Case 3
% eta_end = [2 -3 deg2rad(0)]';
                                % eta_0 = Start position of ship.
                                % eta_end = Dock position and orientation. 
                                % psi_dock = 0, docking on dock's starboard
                                % psi_dock = 180, dock on dock's port side.
d_ref = 0.05;                   % Desired distance from dock at end.
% - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - &&
%% - - - - - - - - - - - Trajectory generator - - - - - - - - - - - - - &&
lambda = 0.25;
% - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - &&
%% - - - - - - - - - - -  DP controller - - - - - - - - - - - - - - - - &&
% - - - Constant inputs
mu1 = 0.025;
mu2 = 0.00;
u_approach = 0.075;             % Desired tracking speed during Phase 1
u_dock = 0.0075;                % Desired docking speed during Phase 2.
% - - - Gains
T1_p = diag([0.75 0.5]);        % Motion control gains
T1_psi = 1.5;                   % Motion control gains
T2 = diag([0.75 0.5 1.5]);      % Motion control gains
% - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - &&
%% - - - - - - - - - - - Observer - - - - - - - - - - - - - - - - - - - &&
K2 = diag([0.05 0.50 0.75]);    % Observer eta gain
K3 = diag([0.15 0.40 0.50]);    % Observer bias gain
K4 = diag([5.00 7.50 0.75]);    % Observer nu gain
% - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - &&
%% - - - - - - - - - - - Simulation parameters - - - - - - - - - - - - -&&
sim_time = 300;                 % Simulation time
current = [-0.0071, 0.0071]';   % Current speed in north and east direction
t_dang = [0,0];%[150, 250];     % Danger [start, stop]. [0,0] if no danger.
                                % To change  preferred reaction, go into 
                                % "Motion Control"-block in simulink.
                                %
bias_b = [0.0, 0.0, 0.0];       % Constant outer bias
d1_x = 0.4;                     % Proximity sensor 1 location in body x
d1_y = 0.12;                    % Proximity sensor 1 location in body y
d2_x = -0.5;                    % Proximity sensor 2 location in body x
d2_y = 0.12;                    % Proximity sensor 2 location in body y
h = 0.01;                       % Time step of simulation
% - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - &&
%% - - - - - - - - - - - Simulate - - - - - - - - - - - - - - - - - - - &&
constant_matrices               % Load constant matrices M and D
addpath(genpath(pwd));          % Adding subfolders to path for plotting
sim simulate_CSE1               % Start simulation of simulate_CSE1.slx
close all                       % Close all open figures
figure(1)
case_NED_tiledlayout            % Plot NED
figure(2)
case_etad_etahat_tiledlayout    % Plot eta vs desired eta
figure(3)
observer_nu_tiledlayout         % Plot nu vs true nu
figure(4)
case_tau_tiledlayout            % Plot tau vs desired tau
figure(5)
case_prox_meas_tiledlayout      % Plot proximity sensors measurements
figure(6)
observer_eta_tiledlayout        % Plot estimated vs measured eta
figure(7)
observer_eta_zoom_tiledlayout   % Plot zoomed in estimated vs measured eta
figure(8)
observer_bias_tiledlayout       % Plot estimated bias
figure(9)
case_etaerr_tiledlayout         % Plot eta-eta_d
% - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - &&